mu_state library

Classes

MuConsumer<S>
A Flutter widget which combines MuBuilder and MuListener into one.
MuListener<S>
A Flutter widget that performs side effects in response to state changes.
MuMultiBuilder
A Flutter widget that listens to multiple MuLogic instances and rebuilds when any of them change.
MuMultiListener
A Flutter widget that merges multiple MuListener widgets into one.
MuMultiProvider
A Flutter widget that merges multiple MuProvider widgets into one.
MuProvider<T>
A Flutter widget that makes any value available to descendant widgets via dependency injection.

Mixins

MuComparable
A lightweight mixin that provides equality comparison for state classes.

Extensions

MuContext on BuildContext
Extension on BuildContext to provide convenient access to provided values.

Typedefs

MuBuilder<L> = ValueListenableBuilder<L>
A typedef for ValueListenableBuilder that rebuilds widgets when state changes.
MuListenerBuilder = Widget Function(Widget child)
Signature for the listener builder function used by MuMultiListener.
MuListenerCallback<S> = void Function(BuildContext context, S state)
MuLogic<S> = ValueNotifier<S>
A typedef for ValueNotifier that serves as the foundation for business logic.